import { ThemeIcons, ThemeIconSpec } from '@fluentui/styles';

const fontIcon = (content: string, fontFamily: string): ThemeIconSpec => ({
  icon: { content: `'\\${content}'`, fontFamily },
});

const normal = (content: string) => fontIcon(content, '"Font Awesome 5 Free"');
const outline = (content: string) => fontIcon(content, '"Font Awesome 5 Free"');
const brand = (content: string) => fontIcon(content, '"Font Awesome 5 Brands"');

// Originally generated from:
// https://github.com/Semantic-Org/Semantic-UI-CSS/blob/master/components/icon.css
// Corrections were made to duplicate icon names and incorrectly mapped alternates
const fontAwesomeIcons: ThemeIcons = {
  // Deprecated *In/Out Naming Conflict)
  'linkedin in': brand('f0e1'),
  'zoom in': normal('f00e'),
  'zoom out': normal('f010'),
  'sign in': normal('f2f6'),
  'in cart': normal('f218'),
  'log out': normal('f2f5'),
  'sign out': normal('f2f5'),

  // Icons
  '500px': brand('f26e'),
  'accessible icon': brand('f368'),
  accusoft: brand('f369'),
  'address book': normal('f2b9'),
  'address card': normal('f2bb'),
  adjust: normal('f042'),
  adn: brand('f170'),
  adversal: brand('f36a'),
  affiliatetheme: brand('f36b'),
  algolia: brand('f36c'),
  'align center': normal('f037'),
  'align justify': normal('f039'),
  'align left': normal('f036'),
  'align right': normal('f038'),
  amazon: brand('f270'),
  'amazon pay': brand('f42c'),
  ambulance: normal('f0f9'),
  'american sign language interpreting': normal('f2a3'),
  amilia: brand('f36d'),
  anchor: normal('f13d'),
  android: brand('f17b'),
  angellist: brand('f209'),
  'angle double down': normal('f103'),
  'angle double left': normal('f100'),
  'angle double right': normal('f101'),
  'angle double up': normal('f102'),
  'angle down': normal('f107'),
  'angle left': normal('f104'),
  'angle right': normal('f105'),
  'angle up': normal('f106'),
  angrycreative: brand('f36e'),
  angular: brand('f420'),
  'app store': brand('f36f'),
  'app store ios': brand('f370'),
  apper: brand('f371'),
  apple: brand('f179'),
  'apple pay': brand('f415'),
  archive: normal('f187'),
  'arrow alternate circle down': normal('f358'),
  'arrow alternate circle left': normal('f359'),
  'arrow alternate circle right': normal('f35a'),
  'arrow alternate circle up': normal('f35b'),
  'arrow circle down': normal('f0ab'),
  'arrow circle left': normal('f0a8'),
  'arrow circle right': normal('f0a9'),
  'arrow circle up': normal('f0aa'),
  'arrow down': normal('f063'),
  'arrow left': normal('f060'),
  'arrow right': normal('f061'),
  'arrow up': normal('f062'),
  'arrows alternate': normal('f0b2'),
  'arrows alternate horizontal': normal('f337'),
  'arrows alternate vertical': normal('f338'),
  'assistive listening systems': normal('f2a2'),
  asterisk: normal('f069'),
  asymmetrik: brand('f372'),
  at: normal('f1fa'),
  audible: brand('f373'),
  'audio description': normal('f29e'),
  autoprefixer: brand('f41c'),
  avianex: brand('f374'),
  aviato: brand('f421'),
  aws: brand('f375'),
  backward: brand('f04a'),
  'balance scale': normal('f24e'),
  ban: brand('f05e'),
  'band aid': normal('f462'),
  bandcamp: brand('f2d5'),
  barcode: normal('f02a'),
  bars: normal('f0c9'),
  'baseball ball': normal('f433'),
  'basketball ball': normal('f434'),
  bath: normal('f2cd'),
  'battery empty': normal('f244'),
  'battery full': normal('f240'),
  'battery half': normal('f242'),
  'battery quarter': normal('f243'),
  'battery three quarters': normal('f241'),
  bed: normal('f236'),
  beer: normal('f0fc'),
  behance: brand('f1b4'),
  'behance square': brand('f1b5'),
  bell: normal('f0f3'),
  'bell slash': normal('f1f6'),
  bicycle: normal('f206'),
  bimobject: brand('f378'),
  binoculars: normal('f1e5'),
  'birthday cake': normal('f1fd'),
  bitbucket: brand('f171'),
  bitcoin: brand('f379'),
  bity: brand('f37a'),
  'black tie': normal('f27e'),
  blackberry: brand('f37b'),
  blind: normal('f29d'),
  blogger: brand('f37c'),
  'blogger b': brand('f37d'),
  bluetooth: brand('f293'),
  'bluetooth b': brand('f294'),
  bold: normal('f032'),
  bolt: normal('f0e7'),
  bomb: normal('f1e2'),
  book: normal('f02d'),
  bookmark: normal('f02e'),
  'bowling ball': normal('f436'),
  box: normal('f466'),
  boxes: normal('f468'),
  braille: normal('f2a1'),
  briefcase: normal('f0b1'),
  btc: brand('f15a'),
  bug: normal('f188'),
  building: normal('f1ad'),
  bullhorn: normal('f0a1'),
  bullseye: normal('f140'),
  buromobelexperte: brand('f37f'),
  bus: normal('f207'),
  buysellads: brand('f20d'),
  calculator: normal('f1ec'),
  calendar: normal('f133'),
  'calendar alternate': normal('f073'),
  'calendar check': normal('f274'),
  'calendar minus': normal('f272'),
  'calendar plus': normal('f271'),
  'calendar times': normal('f273'),
  camera: normal('f030'),
  'camera retro': normal('f083'),
  car: normal('f1b9'),
  'caret down': normal('f0d7'),
  'caret left': normal('f0d9'),
  'caret right': normal('f0da'),
  'caret square down': normal('f150'),
  'caret square left': normal('f191'),
  'caret square right': normal('f152'),
  'caret square up': normal('f151'),
  'caret up': normal('f0d8'),
  'cart arrow down': normal('f218'),
  'cart plus': normal('f217'),
  'cc amazon pay': brand('f42d'),
  'cc amex': brand('f1f3'),
  'cc apple pay': brand('f416'),
  'cc diners club': brand('f24c'),
  'cc discover': brand('f1f2'),
  'cc jcb': brand('f24b'),
  'cc mastercard': brand('f1f1'),
  'cc paypal': brand('f1f4'),
  'cc stripe': brand('f1f5'),
  'cc visa': brand('f1f0'),
  centercode: brand('f380'),
  certificate: normal('f0a3'),
  'chart area': normal('f1fe'),
  'chart bar': normal('f080'),
  'chart line': normal('f201'),
  'chart pie': normal('f200'),
  check: normal('f00c'),
  'check circle': normal('f058'),
  'check square': normal('f14a'),
  chess: normal('f439'),
  'chess bishop': normal('f43a'),
  'chess board': normal('f43c'),
  'chess king': normal('f43f'),
  'chess knight': normal('f441'),
  'chess pawn': normal('f443'),
  'chess queen': normal('f445'),
  'chess rook': normal('f447'),
  'chevron circle down': normal('f13a'),
  'chevron circle left': normal('f137'),
  'chevron circle right': normal('f138'),
  'chevron circle up': normal('f139'),
  'chevron down': normal('f078'),
  'chevron left': normal('f053'),
  'chevron right': normal('f054'),
  'chevron up': normal('f077'),
  child: normal('f1ae'),
  chrome: brand('f268'),
  circle: normal('f111'),
  'circle notch': normal('f1ce'),
  clipboard: normal('f328'),
  'clipboard check': normal('f46c'),
  'clipboard list': normal('f46d'),
  clock: normal('f017'),
  clone: normal('f24d'),
  'closed captioning': normal('f20a'),
  cloud: normal('f0c2'),
  cloudscale: brand('f383'),
  cloudsmith: brand('f384'),
  cloudversify: brand('f385'),
  code: normal('f121'),
  'code branch': normal('f126'),
  codepen: brand('f1cb'),
  codiepie: brand('f284'),
  coffee: normal('f0f4'),
  cog: normal('f013'),
  cogs: normal('f085'),
  columns: normal('f0db'),
  comment: normal('f075'),
  'comment alternate': normal('f27a'),
  comments: normal('f086'),
  compass: normal('f14e'),
  compress: normal('f066'),
  connectdevelop: brand('f20e'),
  contao: brand('f26d'),
  copy: normal('f0c5'),
  copyright: normal('f1f9'),
  cpanel: brand('f388'),
  'creative commons': brand('f25e'),
  'credit card': normal('f09d'),
  crop: normal('f125'),
  crosshairs: normal('f05b'),
  css3: brand('f13c'),
  'css3 alternate': brand('f38b'),
  cube: normal('f1b2'),
  cubes: normal('f1b3'),
  cut: normal('f0c4'),
  cuttlefish: brand('f38c'),
  'd and d': brand('f38d'),
  dashcube: brand('f210'),
  database: normal('f1c0'),
  deaf: normal('f2a4'),
  delicious: brand('f1a5'),
  deploydog: brand('f38e'),
  deskpro: brand('f38f'),
  desktop: normal('f108'),
  deviantart: brand('f1bd'),
  digg: brand('f1a6'),
  'digital ocean': brand('f391'),
  discord: brand('f392'),
  discourse: brand('f393'),
  dna: normal('f471'),
  dochub: brand('f394'),
  docker: brand('f395'),
  'dollar sign': normal('f155'),
  dolly: normal('f472'),
  'dolly flatbed': normal('f474'),
  'dot circle': normal('f192'),
  download: normal('f019'),
  draft2digital: brand('f396'),
  dribbble: brand('f17d'),
  'dribbble square': brand('f397'),
  dropbox: brand('f16b'),
  drupal: brand('f1a9'),
  dyalog: brand('f399'),
  earlybirds: brand('f39a'),
  edge: brand('f282'),
  edit: normal('f044'),
  eject: normal('f052'),
  elementor: brand('f430'),
  'ellipsis horizontal': normal('f141'),
  'ellipsis vertical': normal('f142'),
  ember: brand('f423'),
  empire: brand('f1d1'),
  envelope: normal('f0e0'),
  'envelope open': normal('f2b6'),
  'envelope square': normal('f199'),
  envira: brand('f299'),
  eraser: normal('f12d'),
  erlang: brand('f39d'),
  ethereum: brand('f42e'),
  etsy: brand('f2d7'),
  'euro sign': normal('f153'),
  'exchange alternate': normal('f362'),
  exclamation: normal('f12a'),
  'exclamation circle': normal('f06a'),
  'exclamation triangle': normal('f071'),
  expand: normal('f065'),
  'expand arrows alternate': normal('f31e'),
  expeditedssl: brand('f23e'),
  'external alternate': normal('f35d'),
  'external square alternate': normal('f360'),
  eye: normal('f06e'),
  'eye dropper': normal('f1fb'),
  'eye slash': normal('f070'),
  facebook: brand('f09a'),
  'facebook f': brand('f39e'),
  'facebook messenger': brand('f39f'),
  'facebook square': brand('f082'),
  'fast backward': normal('f049'),
  'fast forward': normal('f050'),
  fax: normal('f1ac'),
  female: normal('f182'),
  'fighter jet': normal('f0fb'),
  file: normal('f15b'),
  'file alternate': normal('f15c'),
  'file archive': normal('f1c6'),
  'file audio': normal('f1c7'),
  'file code': normal('f1c9'),
  'file excel': normal('f1c3'),
  'file image': normal('f1c5'),
  'file pdf': normal('f1c1'),
  'file powerpoint': normal('f1c4'),
  'file video': normal('f1c8'),
  'file word': normal('f1c2'),
  film: normal('f008'),
  filter: normal('f0b0'),
  fire: normal('f06d'),
  'fire extinguisher': normal('f134'),
  firefox: brand('f269'),
  'first aid': normal('f479'),
  'first order': brand('f2b0'),
  firstdraft: brand('f3a1'),
  flag: normal('f024'),
  'flag checkered': normal('f11e'),
  flask: normal('f0c3'),
  flickr: brand('f16e'),
  flipboard: brand('f44d'),
  fly: brand('f417'),
  folder: normal('f07b'),
  'folder open': normal('f07c'),
  font: normal('f031'),
  'font awesome': brand('f2b4'),
  'font awesome alternate': brand('f35c'),
  'font awesome flag': brand('f425'),
  fonticons: brand('f280'),
  'fonticons fi': brand('f3a2'),
  'football ball': normal('f44e'),
  'fort awesome': brand('f286'),
  'fort awesome alternate': brand('f3a3'),
  forumbee: brand('f211'),
  forward: normal('f04e'),
  foursquare: brand('f180'),
  'free code camp': brand('f2c5'),
  freebsd: brand('f3a4'),
  frown: normal('f119'),
  futbol: normal('f1e3'),
  gamepad: normal('f11b'),
  gavel: normal('f0e3'),
  gem: normal('f3a5'),
  genderless: normal('f22d'),
  'get pocket': brand('f265'),
  gg: brand('f260'),
  'gg circle': brand('f261'),
  gift: normal('f06b'),
  git: brand('f1d3'),
  'git square': brand('f1d2'),
  github: brand('f09b'),
  'github alternate': brand('f113'),
  'github square': brand('f092'),
  gitkraken: brand('f3a6'),
  gitlab: brand('f296'),
  gitter: brand('f426'),
  'glass martini': normal('f000'),
  glide: brand('f2a5'),
  'glide g': brand('f2a6'),
  globe: normal('f0ac'),
  gofore: brand('f3a7'),
  'golf ball': normal('f450'),
  goodreads: brand('f3a8'),
  'goodreads g': brand('f3a9'),
  google: brand('f1a0'),
  'google drive': brand('f3aa'),
  'google play': brand('f3ab'),
  'google plus': brand('f2b3'),
  'google plus g': brand('f0d5'),
  'google plus square': brand('f0d4'),
  'google wallet': brand('f1ee'),
  'graduation cap': normal('f19d'),
  gratipay: brand('f184'),
  grav: brand('f2d6'),
  gripfire: brand('f3ac'),
  grunt: brand('f3ad'),
  gulp: brand('f3ae'),
  'h square': normal('f0fd'),
  'hacker news': brand('f1d4'),
  'hacker news square': brand('f3af'),
  'hand lizard': normal('f258'),
  'hand paper': normal('f256'),
  'hand peace': normal('f25b'),
  'hand point down': normal('f0a7'),
  'hand point left': normal('f0a5'),
  'hand point right': normal('f0a4'),
  'hand point up': normal('f0a6'),
  'hand pointer': normal('f25a'),
  'hand rock': normal('f255'),
  'hand scissors': normal('f257'),
  'hand spock': normal('f259'),
  handshake: normal('f2b5'),
  hashtag: normal('f292'),
  hdd: normal('f0a0'),
  heading: normal('f1dc'),
  headphones: normal('f025'),
  heart: normal('f004'),
  heartbeat: normal('f21e'),
  hips: brand('f452'),
  'hire a helper': brand('f3b0'),
  history: normal('f1da'),
  'hockey puck': normal('f453'),
  home: normal('f015'),
  hooli: brand('f427'),
  hospital: normal('f0f8'),
  'hospital symbol': normal('f47e'),
  hotjar: brand('f3b1'),
  hourglass: normal('f254'),
  'hourglass end': normal('f253'),
  'hourglass half': normal('f252'),
  'hourglass start': normal('f251'),
  houzz: brand('f27c'),
  html5: brand('f13b'),
  hubspot: brand('f3b2'),
  'i cursor': normal('f246'),
  'id badge': normal('f2c1'),
  'id card': normal('f2c2'),
  image: normal('f03e'),
  images: normal('f302'),
  imdb: brand('f2d8'),
  inbox: normal('f01c'),
  indent: normal('f03c'),
  industry: normal('f275'),
  info: normal('f129'),
  'info circle': normal('f05a'),
  instagram: brand('f16d'),
  'internet explorer': brand('f26b'),
  ioxhost: brand('f208'),
  italic: normal('f033'),
  itunes: brand('f3b4'),
  'itunes note': brand('f3b5'),
  jenkins: brand('f3b6'),
  joget: brand('f3b7'),
  joomla: brand('f1aa'),
  js: brand('f3b8'),
  'js square': brand('f3b9'),
  jsfiddle: brand('f1cc'),
  key: normal('f084'),
  keyboard: normal('f11c'),
  keycdn: brand('f3ba'),
  kickstarter: brand('f3bb'),
  'kickstarter k': brand('f3bc'),
  korvue: brand('f42f'),
  language: normal('f1ab'),
  laptop: normal('f109'),
  laravel: brand('f3bd'),
  lastfm: brand('f202'),
  'lastfm square': brand('f203'),
  leaf: normal('f06c'),
  leanpub: brand('f212'),
  lemon: normal('f094'),
  less: brand('f41d'),
  'level down alternate': normal('f3be'),
  'level up alternate': normal('f3bf'),
  'life ring': normal('f1cd'),
  lightbulb: normal('f0eb'),
  linechat: brand('f3c0'),
  linkify: normal('f0c1'),
  linkedin: brand('f08c'),
  'linkedin alt': brand('f0e1'),
  linode: brand('f2b8'),
  linux: brand('f17c'),
  'lira sign': normal('f195'),
  list: normal('f03a'),
  'list alternate': normal('f022'),
  'list ol': normal('f0cb'),
  'list ul': normal('f0ca'),
  'location arrow': normal('f124'),
  lock: normal('f023'),
  'lock open': normal('f3c1'),
  'long arrow alternate down': normal('f309'),
  'long arrow alternate left': normal('f30a'),
  'long arrow alternate right': normal('f30b'),
  'long arrow alternate up': normal('f30c'),
  'low vision': normal('f2a8'),
  lyft: brand('f3c3'),
  magento: brand('f3c4'),
  magic: normal('f0d0'),
  magnet: normal('f076'),
  male: normal('f183'),
  map: normal('f279'),
  'map marker': normal('f041'),
  'map marker alternate': normal('f3c5'),
  'map pin': normal('f276'),
  'map signs': normal('f277'),
  mars: normal('f222'),
  'mars double': normal('f227'),
  'mars stroke': normal('f229'),
  'mars stroke horizontal': normal('f22b'),
  'mars stroke vertical': normal('f22a'),
  maxcdn: brand('f136'),
  medapps: brand('f3c6'),
  medium: brand('f23a'),
  'medium m': brand('f3c7'),
  medkit: normal('f0fa'),
  medrt: brand('f3c8'),
  meetup: brand('f2e0'),
  meh: normal('f11a'),
  mercury: normal('f223'),
  microchip: normal('f2db'),
  microphone: normal('f130'),
  'microphone slash': normal('f131'),
  microsoft: brand('f3ca'),
  minus: normal('f068'),
  'minus circle': normal('f056'),
  'minus square': normal('f146'),
  mix: brand('f3cb'),
  mixcloud: brand('f289'),
  mizuni: brand('f3cc'),
  mobile: normal('f10b'),
  'mobile alternate': normal('f3cd'),
  modx: brand('f285'),
  monero: brand('f3d0'),
  'money bill alternate': normal('f3d1'),
  moon: normal('f186'),
  motorcycle: normal('f21c'),
  'mouse pointer': normal('f245'),
  music: normal('f001'),
  napster: brand('f3d2'),
  neuter: normal('f22c'),
  newspaper: normal('f1ea'),
  'nintendo switch': brand('f418'),
  node: brand('f419'),
  'node js': brand('f3d3'),
  npm: brand('f3d4'),
  ns8: brand('f3d5'),
  nutritionix: brand('f3d6'),
  'object group': normal('f247'),
  'object ungroup': normal('f248'),
  odnoklassniki: brand('f263'),
  'odnoklassniki square': brand('f264'),
  opencart: brand('f23d'),
  openid: brand('f19b'),
  opera: brand('f26a'),
  'optin monster': brand('f23c'),
  osi: brand('f41a'),
  outdent: normal('f03b'),
  page4: brand('f3d7'),
  pagelines: brand('f18c'),
  'paint brush': normal('f1fc'),
  palfed: brand('f3d8'),
  pallet: normal('f482'),
  'paper plane': normal('f1d8'),
  paperclip: normal('f0c6'),
  paragraph: normal('f1dd'),
  paste: normal('f0ea'),
  patreon: brand('f3d9'),
  pause: normal('f04c'),
  'pause circle': normal('f28b'),
  paw: normal('f1b0'),
  paypal: brand('f1ed'),
  'pen square': normal('f14b'),
  'pencil alternate': normal('f303'),
  percent: normal('f295'),
  periscope: brand('f3da'),
  phabricator: brand('f3db'),
  'phoenix framework': brand('f3dc'),
  phone: normal('f095'),
  'phone square': normal('f098'),
  'phone volume': normal('f2a0'),
  php: brand('f457'),
  'pied piper': brand('f2ae'),
  'pied piper alternate': brand('f1a8'),
  'pied piper pp': brand('f1a7'),
  pills: normal('f484'),
  pinterest: brand('f0d2'),
  'pinterest p': brand('f231'),
  'pinterest square': brand('f0d3'),
  plane: normal('f072'),
  play: normal('f04b'),
  'play circle': normal('f144'),
  playstation: brand('f3df'),
  plug: normal('f1e6'),
  plus: normal('f067'),
  'plus circle': normal('f055'),
  'plus square': normal('f0fe'),
  podcast: normal('f2ce'),
  'pound sign': normal('f154'),
  'power off': normal('f011'),
  print: normal('f02f'),
  'product hunt': brand('f288'),
  pushed: brand('f3e1'),
  'puzzle piece': normal('f12e'),
  python: brand('f3e2'),
  qq: brand('f1d6'),
  qrcode: normal('f029'),
  question: normal('f128'),
  'question circle': normal('f059'),
  quidditch: normal('f458'),
  quinscape: brand('f459'),
  quora: brand('f2c4'),
  'quote left': normal('f10d'),
  'quote right': normal('f10e'),
  random: normal('f074'),
  ravelry: brand('f2d9'),
  react: brand('f41b'),
  rebel: brand('f1d0'),
  recycle: normal('f1b8'),
  redriver: brand('f3e3'),
  reddit: brand('f1a1'),
  'reddit alien': brand('f281'),
  'reddit square': brand('f1a2'),
  redo: normal('f01e'),
  'redo alternate': normal('f2f9'),
  registered: normal('f25d'),
  rendact: brand('f3e4'),
  renren: brand('f18b'),
  reply: normal('f3e5'),
  'reply all': normal('f122'),
  replyd: brand('f3e6'),
  resolving: brand('f3e7'),
  retweet: normal('f079'),
  road: normal('f018'),
  rocket: normal('f135'),
  rocketchat: brand('f3e8'),
  rockrms: brand('f3e9'),
  rss: normal('f09e'),
  'rss square': normal('f143'),
  'ruble sign': normal('f158'),
  'rupee sign': normal('f156'),
  safari: brand('f267'),
  sass: brand('f41e'),
  save: normal('f0c7'),
  schlix: brand('f3ea'),
  scribd: brand('f28a'),
  search: normal('f002'),
  'search minus': normal('f010'),
  'search plus': normal('f00e'),
  searchengin: brand('f3eb'),
  sellcast: brand('f2da'),
  sellsy: brand('f213'),
  server: normal('f233'),
  servicestack: brand('f3ec'),
  share: normal('f064'),
  'share alternate': normal('f1e0'),
  'share alternate square': normal('f1e1'),
  'share square': normal('f14d'),
  'shekel sign': normal('f20b'),
  'shield alternate': normal('f3ed'),
  ship: normal('f21a'),
  'shipping fast': normal('f48b'),
  shirtsinbulk: brand('f214'),
  'shopping bag': normal('f290'),
  'shopping basket': normal('f291'),
  'shopping cart': normal('f07a'),
  shower: normal('f2cc'),
  'sign language': normal('f2a7'),
  signal: normal('f012'),
  simplybuilt: brand('f215'),
  sistrix: brand('f3ee'),
  sitemap: normal('f0e8'),
  skyatlas: brand('f216'),
  skype: brand('f17e'),
  slack: brand('f198'),
  'slack hash': brand('f3ef'),
  'sliders horizontal': normal('f1de'),
  slideshare: brand('f1e7'),
  smile: normal('f118'),
  snapchat: brand('f2ab'),
  'snapchat ghost': brand('f2ac'),
  'snapchat square': brand('f2ad'),
  snowflake: normal('f2dc'),
  sort: normal('f0dc'),
  'sort alphabet down': normal('f15d'),
  'sort alphabet up': normal('f15e'),
  'sort amount down': normal('f160'),
  'sort amount up': normal('f161'),
  'sort down': normal('f0dd'),
  'sort numeric down': normal('f162'),
  'sort numeric up': normal('f163'),
  'sort up': normal('f0de'),
  soundcloud: brand('f1be'),
  'space shuttle': normal('f197'),
  speakap: brand('f3f3'),
  spinner: normal('f110'),
  spotify: brand('f1bc'),
  square: normal('f0c8'),
  'square full': normal('f45c'),
  'stack exchange': brand('f18d'),
  'stack overflow': brand('f16c'),
  star: normal('f005'),
  'star half': normal('f089'),
  staylinked: brand('f3f5'),
  steam: brand('f1b6'),
  'steam square': brand('f1b7'),
  'steam symbol': brand('f3f6'),
  'step backward': normal('f048'),
  'step forward': normal('f051'),
  stethoscope: normal('f0f1'),
  'sticker mule': brand('f3f7'),
  'sticky note': normal('f249'),
  stop: normal('f04d'),
  'stop circle': normal('f28d'),
  stopwatch: normal('f2f2'),
  strava: brand('f428'),
  'street view': normal('f21d'),
  strikethrough: normal('f0cc'),
  stripe: brand('f429'),
  'stripe s': brand('f42a'),
  studiovinari: brand('f3f8'),
  stumbleupon: brand('f1a4'),
  'stumbleupon circle': brand('f1a3'),
  subscript: normal('f12c'),
  subway: normal('f239'),
  suitcase: normal('f0f2'),
  sun: normal('f185'),
  superpowers: brand('f2dd'),
  superscript: normal('f12b'),
  supple: brand('f3f9'),
  sync: normal('f021'),
  'sync alternate': normal('f2f1'),
  syringe: normal('f48e'),
  table: normal('f0ce'),
  'table tennis': normal('f45d'),
  tablet: normal('f10a'),
  'tablet alternate': normal('f3fa'),
  'tachometer alternate': normal('f3fd'),
  tag: normal('f02b'),
  tags: normal('f02c'),
  tasks: normal('f0ae'),
  taxi: normal('f1ba'),
  telegram: brand('f2c6'),
  'telegram plane': brand('f3fe'),
  'tencent weibo': brand('f1d5'),
  terminal: normal('f120'),
  'text height': normal('f034'),
  'text width': normal('f035'),
  th: normal('f00a'),
  'th large': normal('f009'),
  'th list': normal('f00b'),
  themeisle: brand('f2b2'),
  thermometer: normal('f2c7'),
  'thermometer empty': normal('f2cb'),
  'thermometer full': normal('f2c7'),
  'thermometer half': normal('f2c9'),
  'thermometer quarter': normal('f2ca'),
  'thermometer three quarters': normal('f2c8'),
  'thumbs down': normal('f165'),
  'thumbs up': normal('f164'),
  thumbtack: normal('f08d'),
  'ticket alternate': normal('f3ff'),
  times: normal('f00d'),
  'times circle': normal('f057'),
  tint: normal('f043'),
  'toggle off': normal('f204'),
  'toggle on': normal('f205'),
  trademark: normal('f25c'),
  train: normal('f238'),
  transgender: normal('f224'),
  'transgender alternate': normal('f225'),
  trash: normal('f1f8'),
  'trash alternate': normal('f2ed'),
  tree: normal('f1bb'),
  trello: brand('f181'),
  tripadvisor: brand('f262'),
  trophy: normal('f091'),
  truck: normal('f0d1'),
  tty: normal('f1e4'),
  tumblr: brand('f173'),
  'tumblr square': brand('f174'),
  tv: normal('f26c'),
  twitch: brand('f1e8'),
  twitter: brand('f099'),
  'twitter square': brand('f081'),
  typo3: brand('f42b'),
  uber: brand('f402'),
  uikit: brand('f403'),
  umbrella: normal('f0e9'),
  underline: normal('f0cd'),
  undo: normal('f0e2'),
  'undo alternate': normal('f2ea'),
  uniregistry: brand('f404'),
  'universal access': normal('f29a'),
  university: normal('f19c'),
  unlink: normal('f127'),
  unlock: normal('f09c'),
  'unlock alternate': normal('f13e'),
  untappd: brand('f405'),
  upload: normal('f093'),
  usb: brand('f287'),
  user: normal('f007'),
  'user circle': normal('f2bd'),
  'user md': normal('f0f0'),
  'user plus': normal('f234'),
  'user secret': normal('f21b'),
  'user times': normal('f235'),
  users: normal('f0c0'),
  ussunnah: brand('f407'),
  'utensil spoon': normal('f2e5'),
  utensils: normal('f2e7'),
  vaadin: brand('f408'),
  venus: normal('f221'),
  'venus double': normal('f226'),
  'venus mars': normal('f228'),
  viacoin: brand('f237'),
  viadeo: brand('f2a9'),
  'viadeo square': brand('f2aa'),
  viber: brand('f409'),
  video: normal('f03d'),
  vimeo: brand('f40a'),
  'vimeo square': brand('f194'),
  'vimeo v': brand('f27d'),
  vine: brand('f1ca'),
  vk: brand('f189'),
  vnv: brand('f40b'),
  'volleyball ball': normal('f45f'),
  'volume down': normal('f027'),
  'volume off': normal('f026'),
  'volume up': normal('f028'),
  vuejs: brand('f41f'),
  warehouse: normal('f494'),
  weibo: brand('f18a'),
  weight: normal('f496'),
  weixin: brand('f1d7'),
  whatsapp: brand('f232'),
  'whatsapp square': brand('f40c'),
  wheelchair: normal('f193'),
  whmcs: brand('f40d'),
  wifi: normal('f1eb'),
  'wikipedia w': brand('f266'),
  'window close': normal('f410'),
  'window maximize': normal('f2d0'),
  'window minimize': normal('f2d1'),
  'window restore': normal('f2d2'),
  windows: brand('f17a'),
  'won sign': normal('f159'),
  wordpress: brand('f19a'),
  'wordpress simple': brand('f411'),
  wpbeginner: brand('f297'),
  wpexplorer: brand('f2de'),
  wpforms: brand('f298'),
  wrench: normal('f0ad'),
  xbox: brand('f412'),
  xing: brand('f168'),
  'xing square': brand('f169'),
  'y combinator': brand('f23b'),
  yahoo: brand('f19e'),
  yandex: brand('f413'),
  'yandex international': brand('f414'),
  yelp: brand('f1e9'),
  'yen sign': normal('f157'),
  yoast: brand('f2b1'),
  youtube: brand('f167'),
  'youtube square': brand('f431'),

  // Aliases
  'chess rock': normal('f447'),
  'ordered list': normal('f0cb'),
  'unordered list': normal('f0ca'),
  'user doctor': normal('f0f0'),
  shield: normal('f3ed'),
  puzzle: normal('f12e'),
  'credit card amazon pay': brand('f42d'),
  'credit card american express': brand('f1f3'),
  'credit card diners club': brand('f24c'),
  'credit card discover': brand('f1f2'),
  'credit card jcb': brand('f24b'),
  'credit card mastercard': brand('f1f1'),
  'credit card paypal': brand('f1f4'),
  'credit card stripe': brand('f1f5'),
  'credit card visa': brand('f1f0'),
  'add circle': normal('f055'),
  'add square': normal('f0fe'),
  'add to calendar': normal('f271'),
  'add to cart': normal('f217'),
  'add user': normal('f234'),
  add: normal('f067'),
  'alarm mute': normal('f1f6'),
  alarm: normal('f0f3'),
  ald: normal('f2a2'),
  als: normal('f2a2'),
  'american express card': brand('f1f3'),
  'american express': brand('f1f3'),
  amex: brand('f1f3'),
  announcement: normal('f0a1'),
  'area chart': normal('f1fe'),
  'area graph': normal('f1fe'),
  'arrow down cart': normal('f218'),
  asexual: normal('f22d'),
  'asl interpreting': normal('f2a3'),
  asl: normal('f2a3'),
  'assistive listening devices': normal('f2a2'),
  attach: normal('f0c6'),
  attention: normal('f06a'),
  balance: normal('f24e'),
  bar: normal('f0fc'),
  bathtub: normal('f2cd'),
  'battery four': normal('f240'),
  'battery high': normal('f241'),
  'battery low': normal('f243'),
  'battery medium': normal('f242'),
  'battery one': normal('f243'),
  'battery three': normal('f241'),
  'battery two': normal('f242'),
  'battery zero': normal('f244'),
  birthday: normal('f1fd'),
  'block layout': normal('f009'),
  'bluetooth alternative': brand('f294'),
  'broken chain': normal('f127'),
  browser: normal('f022'),
  'call square': normal('f098'),
  call: normal('f095'),
  cancel: normal('f00d'),
  cart: normal('f07a'),
  cc: normal('f20a'),
  chain: normal('f0c1'),
  chat: normal('f075'),
  'checked calendar': normal('f274'),
  checkmark: normal('f00c'),
  'circle notched': normal('f1ce'),
  close: normal('f00d'),
  cny: normal('f157'),
  cocktail: normal('f000'),
  commenting: normal('f27a'),
  computer: normal('f108'),
  configure: normal('f0ad'),
  content: normal('f0c9'),
  deafness: normal('f2a4'),
  'delete calendar': normal('f273'),
  delete: normal('f00d'),
  detective: normal('f21b'),
  'diners club card': brand('f24c'),
  'diners club': brand('f24c'),
  'discover card': brand('f1f2'),
  discover: brand('f1f2'),
  discussions: normal('f086'),
  doctor: normal('f0f0'),
  dollar: normal('f155'),
  dont: normal('f05e'),
  dribble: brand('f17d'),
  'drivers license': normal('f2c2'),
  dropdown: normal('f0d7'),
  eercast: normal('f2da'),
  emergency: normal('f0f9'),
  'envira gallery': normal('f299'),
  erase: normal('f12d'),
  eur: normal('f153'),
  euro: normal('f153'),
  eyedropper: normal('f1fb'),
  fa: normal('f2b4'),
  factory: normal('f275'),
  favorite: normal('f005'),
  feed: normal('f09e'),
  'female homosexual': normal('f226'),
  'file text': normal('f15c'),
  find: normal('f1e5'),
  'five hundred pixels': brand('f26e'),
  fork: normal('f126'),
  game: normal('f11b'),
  gay: normal('f227'),
  gbp: normal('f154'),
  gittip: normal('f184'),
  'google plus circle': normal('f2b3'),
  'google plus official': normal('f2b3'),
  grab: normal('f255'),
  graduation: normal('f19d'),
  'grid layout': normal('f00a'),
  group: normal('f0c0'),
  h: normal('f0fd'),
  'hand victory': normal('f25b'),
  handicap: normal('f193'),
  'hard of hearing': normal('f2a4'),
  header: normal('f1dc'),
  'help circle': normal('f059'),
  help: normal('f128'),
  heterosexual: normal('f228'),
  hide: normal('f070'),
  hotel: normal('f236'),
  'hourglass four': normal('f254'),
  'hourglass full': normal('f254'),
  'hourglass one': normal('f251'),
  'hourglass three': normal('f253'),
  'hourglass two': normal('f252'),
  idea: normal('f0eb'),
  ils: normal('f20b'),
  'in-cart': normal('f218'),
  inr: normal('f156'),
  intergender: normal('f224'),
  intersex: normal('f224'),
  'japan credit bureau card': brand('f24b'),
  'japan credit bureau': brand('f24b'),
  jcb: normal('f24b'),
  jpy: normal('f157'),
  krw: normal('f159'),
  lab: normal('f0c3'),
  law: normal('f24e'),
  legal: normal('f0e3'),
  lesbian: normal('f226'),
  lightning: normal('f0e7'),
  like: normal('f004'),
  'line graph': normal('f201'),
  'linkedin square': brand('f08c'),
  lira: normal('f195'),
  'list layout': normal('f00b'),
  magnify: normal('f00e'),
  'mail forward': normal('f064'),
  'mail square': normal('f199'),
  mail: normal('f0e0'),
  'male homosexual': normal('f227'),
  man: normal('f222'),
  marker: normal('f041'),
  'mars alternate': normal('f229'),
  'mars horizontal': normal('f22b'),
  'mars vertical': normal('f22a'),
  'mastercard card': brand('f1f1'),
  mastercard: brand('f1f1'),
  'microsoft edge': brand('f282'),
  military: normal('f0fb'),
  'ms edge': brand('f282'),
  mute: normal('f131'),
  'new pied piper': brand('f2ae'),
  'non binary transgender': normal('f223'),
  'numbered list': normal('f0cb'),
  optinmonster: normal('f23c'),
  options: normal('f1de'),
  'other gender horizontal': normal('f22b'),
  'other gender vertical': normal('f22a'),
  'other gender': normal('f229'),
  payment: normal('f09d'),
  'paypal card': brand('f1f4'),
  'pencil square': normal('f14b'),
  photo: normal('f030'),
  picture: normal('f03e'),
  'pie chart': normal('f200'),
  'pie graph': normal('f200'),
  'pied piper hat': normal('f2ae'),
  pin: normal('f08d'),
  'plus cart': normal('f217'),
  pocket: normal('f265'),
  point: normal('f041'),
  'pointing down': normal('f0a7'),
  'pointing left': normal('f0a5'),
  'pointing right': normal('f0a4'),
  'pointing up': normal('f0a6'),
  pound: normal('f154'),
  'power cord': normal('f1e6'),
  power: normal('f011'),
  privacy: normal('f084'),
  'r circle': normal('f25d'),
  rain: normal('f0e9'),
  record: normal('f03d'),
  refresh: normal('f021'),
  'remove circle': normal('f057'),
  'remove from calendar': normal('f272'),
  'remove user': normal('f235'),
  remove: normal('f00d'),
  repeat: normal('f01e'),
  rmb: normal('f157'),
  rouble: normal('f158'),
  rub: normal('f158'),
  ruble: normal('f158'),
  rupee: normal('f156'),
  s15: normal('f2cd'),
  'selected radio': normal('f192'),
  send: normal('f1d8'),
  setting: normal('f013'),
  settings: normal('f085'),
  shekel: normal('f20b'),
  sheqel: normal('f20b'),
  shipping: normal('f0d1'),
  shop: normal('f07a'),
  shuffle: normal('f074'),
  shutdown: normal('f011'),
  sidebar: normal('f0c9'),
  signing: normal('f2a7'),
  signup: normal('f044'),
  sliders: normal('f1de'),
  soccer: normal('f1e3'),
  'sort alphabet ascending': normal('f15d'),
  'sort alphabet descending': normal('f15e'),
  'sort ascending': normal('f0de'),
  'sort content ascending': normal('f160'),
  'sort content descending': normal('f161'),
  'sort descending': normal('f0dd'),
  'sort numeric ascending': normal('f162'),
  'sort numeric descending': normal('f163'),
  sound: normal('f025'),
  spy: normal('f21b'),
  'stripe card': normal('f1f5'),
  student: normal('f19d'),
  talk: normal('f27a'),
  target: normal('f140'),
  teletype: normal('f1e4'),
  television: normal('f26c'),
  'text cursor': normal('f246'),
  'text telephone': normal('f1e4'),
  'theme isle': normal('f2b2'),
  theme: normal('f043'),
  'thumb tack': normal('f08d'),
  time: normal('f017'),
  tm: normal('f25c'),
  'toggle down': normal('f150'),
  'toggle left': normal('f191'),
  'toggle right': normal('f152'),
  'toggle up': normal('f151'),
  translate: normal('f1ab'),
  travel: normal('f0b1'),
  treatment: normal('f0f1'),
  'triangle down': normal('f0d7'),
  'triangle left': normal('f0d9'),
  'triangle right': normal('f0da'),
  'triangle up': normal('f0d8'),
  try: normal('f195'),
  unhide: normal('f06e'),
  unlinkify: normal('f127'),
  unmute: normal('f130'),
  usd: normal('f155'),
  'user cancel': normal('f235'),
  'user close': normal('f235'),
  'user delete': normal('f235'),
  'user x': normal('f235'),
  vcard: normal('f2bb'),
  'video camera': normal('f03d'),
  'video play': normal('f144'),
  'visa card': brand('f1f0'),
  visa: brand('f1f0'),
  'volume control phone': normal('f2a0'),
  wait: normal('f017'),
  'warning circle': normal('f06a'),
  'warning sign': normal('f071'),
  warning: normal('f12a'),
  wechat: brand('f1d7'),
  'wi-fi': normal('f1eb'),
  wikipedia: brand('f266'),
  winner: normal('f091'),
  wizard: normal('f0d0'),
  woman: normal('f221'),
  won: normal('f159'),
  'wordpress beginner': brand('f297'),
  'wordpress forms': brand('f298'),
  world: normal('f0ac'),
  'write square': normal('f14b'),
  x: normal('f00d'),
  yc: brand('f23b'),
  ycombinator: brand('f23b'),
  yen: normal('f157'),
  zip: normal('f187'),
  'zoom-in': normal('f00e'),
  'zoom-out': normal('f010'),
  zoom: normal('f00e'),
  'bitbucket square': brand('f171'),
  'checkmark box': normal('f14a'),
  'circle thin': normal('f111'),
  'cloud download': normal('f381'),
  'cloud upload': normal('f382'),
  compose: normal('f303'),
  conversation: normal('f086'),
  'credit card alternative': normal('f09d'),
  currency: normal('f3d1'),
  dashboard: normal('f3fd'),
  diamond: normal('f3a5'),
  disk: normal('f0a0'),
  exchange: normal('f362'),
  'external share': normal('f14d'),
  'external square': normal('f360'),
  external: normal('f35d'),
  'facebook official': brand('f082'),
  food: normal('f2e7'),
  'hourglass zero': normal('f253'),
  'level down': normal('f3be'),
  'level up': normal('f3bf'),
  logout: normal('f2f5'),
  meanpath: normal('f0c8'),
  money: normal('f3d1'),
  move: normal('f0b2'),
  pencil: normal('f303'),
  protect: normal('f023'),
  radio: normal('f192'),
  'remove bookmark': normal('f02e'),
  'resize horizontal': normal('f337'),
  'resize vertical': normal('f338'),
  'sign-in': normal('f2f6'),
  'sign-out': normal('f2f5'),
  spoon: normal('f2e5'),
  'star half empty': normal('f089'),
  'star half full': normal('f089'),
  ticket: normal('f3ff'),
  'times rectangle': normal('f410'),
  write: normal('f303'),
  'youtube play': brand('f167'),

  //
  // Outline Icons
  //
  'address book outline': outline('f2b9'),
  'address card outline': outline('f2bb'),
  'arrow alternate circle down outline': outline('f358'),
  'arrow alternate circle left outline': outline('f359'),
  'arrow alternate circle right outline': outline('f35a'),
  'arrow alternate circle up outline': outline('f35b'),
  'bell outline': outline('f0f3'),
  'bell slash outline': outline('f1f6'),
  'bookmark outline': outline('f02e'),
  'building outline': outline('f1ad'),
  'calendar outline': outline('f133'),
  'calendar alternate outline': outline('f073'),
  'calendar check outline': outline('f274'),
  'calendar minus outline': outline('f272'),
  'calendar plus outline': outline('f271'),
  'calendar times outline': outline('f273'),
  'caret square down outline': outline('f150'),
  'caret square left outline': outline('f191'),
  'caret square right outline': outline('f152'),
  'caret square up outline': outline('f151'),
  'chart bar outline': outline('f080'),
  'check circle outline': outline('f058'),
  'check square outline': outline('f14a'),
  'circle outline': outline('f111'),
  'clipboard outline': outline('f328'),
  'clock outline': outline('f017'),
  'clone outline': outline('f24d'),
  'closed captioning outline': outline('f20a'),
  'comment outline': outline('f075'),
  'comment alternate outline': outline('f27a'),
  'comments outline': outline('f086'),
  'compass outline': outline('f14e'),
  'copy outline': outline('f0c5'),
  'copyright outline': outline('f1f9'),
  'credit card outline': outline('f09d'),
  'dot circle outline': outline('f192'),
  'edit outline': outline('f044'),
  'envelope outline': outline('f0e0'),
  'envelope open outline': outline('f2b6'),
  'eye slash outline': outline('f070'),
  'file outline': outline('f15b'),
  'file alternate outline': outline('f15c'),
  'file archive outline': outline('f1c6'),
  'file audio outline': outline('f1c7'),
  'file code outline': outline('f1c9'),
  'file excel outline': outline('f1c3'),
  'file image outline': outline('f1c5'),
  'file pdf outline': outline('f1c1'),
  'file powerpoint outline': outline('f1c4'),
  'file video outline': outline('f1c8'),
  'file word outline': outline('f1c2'),
  'flag outline': outline('f024'),
  'folder outline': outline('f07b'),
  'folder open outline': outline('f07c'),
  'frown outline': outline('f119'),
  'futbol outline': outline('f1e3'),
  'gem outline': outline('f3a5'),
  'hand lizard outline': outline('f258'),
  'hand paper outline': outline('f256'),
  'hand peace outline': outline('f25b'),
  'hand point down outline': outline('f0a7'),
  'hand point left outline': outline('f0a5'),
  'hand point right outline': outline('f0a4'),
  'hand point up outline': outline('f0a6'),
  'hand pointer outline': outline('f25a'),
  'hand rock outline': outline('f255'),
  'hand scissors outline': outline('f257'),
  'hand spock outline': outline('f259'),
  'handshake outline': outline('f2b5'),
  'hdd outline': outline('f0a0'),
  'heart outline': outline('f004'),
  'hospital outline': outline('f0f8'),
  'hourglass outline': outline('f254'),
  'id badge outline': outline('f2c1'),
  'id card outline': outline('f2c2'),
  'image outline': outline('f03e'),
  'images outline': outline('f302'),
  'keyboard outline': outline('f11c'),
  'lemon outline': outline('f094'),
  'life ring outline': outline('f1cd'),
  'lightbulb outline': outline('f0eb'),
  'list alternate outline': outline('f022'),
  'map outline': outline('f279'),
  'meh outline': outline('f11a'),
  'minus square outline': outline('f146'),
  'money bill alternate outline': outline('f3d1'),
  'moon outline': outline('f186'),
  'newspaper outline': outline('f1ea'),
  'object group outline': outline('f247'),
  'object ungroup outline': outline('f248'),
  'paper plane outline': outline('f1d8'),
  'pause circle outline': outline('f28b'),
  'play circle outline': outline('f144'),
  'plus square outline': outline('f0fe'),
  'question circle outline': outline('f059'),
  'registered outline': outline('f25d'),
  'save outline': outline('f0c7'),
  'share square outline': outline('f14d'),
  'smile outline': outline('f118'),
  'snowflake outline': outline('f2dc'),
  'square outline': outline('f0c8'),
  'star outline': outline('f005'),
  'star half outline': outline('f089'),
  'sticky note outline': outline('f249'),
  'stop circle outline': outline('f28d'),
  'sun outline': outline('f185'),
  'thumbs down outline': outline('f165'),
  'thumbs up outline': outline('f164'),
  'times circle outline': outline('f057'),
  'trash alternate outline': outline('f2ed'),
  'user outline': outline('f007'),
  'user circle outline': outline('f2bd'),
  'window close outline': outline('f410'),
  'window maximize outline': outline('f2d0'),
  'window minimize outline': outline('f2d1'),
  'window restore outline': outline('f2d2'),
  'disk outline': outline('f369'),

  // Outline Aliases
  'heart empty': outline('f004'),
  'star empty': outline('f089'),
};

export default fontAwesomeIcons;
